@@ -122,7 +122,7 @@ class SystemPrepare:
             repository_options.append(
                 '_install_langs%{0}'.format(':'.join(rpm_locale_list))
             )
-        repo = Repository(
+        repo = Repository.new(
             self.root_bind, package_manager, repository_options
         )
         repo.setup_package_database_configuration()
@@ -140,6 +140,8 @@ class SystemPrepare:
             repo_repository_gpgcheck = xml_repo.get_repository_gpgcheck()
             repo_package_gpgcheck = xml_repo.get_package_gpgcheck()
             repo_sourcetype = xml_repo.get_sourcetype()
+            repo_use_for_bootstrap = \
+                True if xml_repo.get_use_for_bootstrap() else False
             log.info('Setting up repository %s', repo_source)
             log.info('--> Type: {0}'.format(repo_type))
             if repo_sourcetype:
@@ -171,13 +173,13 @@ class SystemPrepare:
                 repo_type, repo_priority, repo_dist, repo_components,
                 repo_user, repo_secret, uri.credentials_file_name(),
                 repo_repository_gpgcheck, repo_package_gpgcheck,
-                repo_sourcetype
+                repo_sourcetype, repo_use_for_bootstrap
             )
             if clear_cache:
                 repo.delete_repo_cache(repo_alias)
             self.uri_list.append(uri)
         repo.cleanup_unused_repos()
-        return PackageManager(
+        return PackageManager.new(
             repo, package_manager
         )
 
@@ -340,8 +342,8 @@ class SystemPrepare:
             try:
                 if manager is None:
                     package_manager = self.xml_state.get_package_manager()
-                    manager = PackageManager(
-                        Repository(self.root_bind, package_manager),
+                    manager = PackageManager.new(
+                        Repository.new(self.root_bind, package_manager),
                         package_manager
                     )
                 self.delete_packages(
@@ -459,8 +461,8 @@ class SystemPrepare:
         at run time such as macros
         """
         package_manager = self.xml_state.get_package_manager()
-        manager = PackageManager(
-            Repository(self.root_bind, package_manager),
+        manager = PackageManager.new(
+            Repository.new(self.root_bind, package_manager),
             package_manager
         )
         manager.clean_leftovers()
