@@ -122,7 +122,7 @@ class ImageResizeTask(CliTask):
         firmware = FirmWare(self.xml_state)
         loop_provider = LoopDevice(image_format.diskname)
         loop_provider.create(overwrite=False)
-        partitioner = Partitioner(
+        partitioner = Partitioner.new(
             firmware.get_partition_table_type(), loop_provider
         )
         partitioner.resize_table()
