@@ -113,7 +113,7 @@ class SystemBuildTask(CliTask):
     * :attr:`manual`
         Instance of Help
     """
-    def process(self):                                      # noqa: C901
+    def process(self):
         """
         Build a system image from the specified description. The
         build command combines the prepare and create commands
