@@ -58,6 +58,17 @@ class TestXMLState:
         assert description.specification == \
             'Testing various configuration states'
 
+    @patch('platform.machine')
+    def test_get_preferences_by_architecture(self, mock_machine):
+        mock_machine.return_value = 'aarch64'
+        state = XMLState(
+            self.description.load()
+        )
+        preferences = state.get_preferences_sections()
+        assert len(preferences) == 3
+        assert preferences[2].get_arch() == 'aarch64'
+        assert state.get_build_type_name() == 'iso'
+
     def test_build_type_primary_selected(self):
         assert self.state.get_build_type_name() == 'oem'
 
@@ -215,6 +226,7 @@ class TestXMLState:
     def test_get_build_type_vagrant_config_section(self):
         vagrant_config = self.state.get_build_type_vagrant_config_section()
         assert vagrant_config.get_provider() == 'libvirt'
+        assert self.boot_state.get_build_type_vagrant_config_section() is None
 
     def test_virtualbox_guest_additions_vagrant_config_section(self):
         assert not self.state.get_vagrant_config_virtualbox_guest_additions()
@@ -231,6 +243,7 @@ class TestXMLState:
 
     def test_get_build_type_vmdisk_section(self):
         assert self.state.get_build_type_vmdisk_section().get_id() == 0
+        assert self.boot_state.get_build_type_vmdisk_section() is None
 
     def test_get_build_type_vmnic_entries(self):
         assert self.state.get_build_type_vmnic_entries()[0].get_interface() \
@@ -239,6 +252,7 @@ class TestXMLState:
 
     def test_get_build_type_vmdvd_section(self):
         assert self.state.get_build_type_vmdvd_section().get_id() == 0
+        assert self.boot_state.get_build_type_vmdvd_section() is None
 
     def test_get_volume_management(self):
         assert self.state.get_volume_management() == 'lvm'
@@ -498,6 +512,17 @@ class TestXMLState:
         state = XMLState(xml_data)
         assert state.get_oemconfig_oem_resize() is False
 
+    def test_get_oemconfig_oem_multipath_scan(self):
+        xml_data = self.description.load()
+        state = XMLState(xml_data, ['vmxFlavour'], 'oem')
+        assert state.get_oemconfig_oem_multipath_scan() is False
+        description = XMLDescription(
+            '../data/example_disk_config.xml'
+        )
+        xml_data = description.load()
+        state = XMLState(xml_data)
+        assert state.get_oemconfig_oem_multipath_scan() is False
+
     def test_get_oemconfig_swap_mbytes(self):
         xml_data = self.description.load()
         state = XMLState(xml_data, ['containerFlavour'], 'docker')
@@ -505,6 +530,13 @@ class TestXMLState:
         state = XMLState(xml_data, ['vmxFlavour'], 'oem')
         assert state.get_oemconfig_swap_mbytes() == 42
 
+    def test_get_oemconfig_swap_name(self):
+        xml_data = self.description.load()
+        state = XMLState(xml_data, ['containerFlavour'], 'docker')
+        assert state.get_oemconfig_swap_name() == 'LVSwap'
+        state = XMLState(xml_data, ['vmxFlavour'], 'oem')
+        assert state.get_oemconfig_swap_name() == 'swap'
+
     def test_get_oemconfig_swap_mbytes_default(self):
         description = XMLDescription(
             '../data/example_btrfs_config.xml'
@@ -886,11 +918,13 @@ class TestXMLState:
 
     def test_get_locale(self):
         assert self.state.get_locale() == ['en_US', 'de_DE']
+        assert self.boot_state.get_locale() is None
 
     def test_get_rpm_locale(self):
         assert self.state.get_rpm_locale() == [
             'POSIX', 'C', 'C.UTF-8', 'en_US', 'de_DE'
         ]
+        assert self.boot_state.get_rpm_locale() is None
 
     def test_set_root_partition_uuid(self):
         assert self.state.get_root_partition_uuid() is None
@@ -920,6 +954,9 @@ class TestXMLState:
         mock_bootloader.return_value = [self.bootloader]
         assert self.state.get_build_type_bootloader_serial_line_setup() == \
             'some-serial'
+        mock_bootloader.return_value = [None]
+        assert self.state.get_build_type_bootloader_serial_line_setup() \
+            is None
 
     @patch('kiwi.xml_parse.type_.get_bootloader')
     def test_get_build_type_bootloader_timeout(self, mock_bootloader):
@@ -932,6 +969,9 @@ class TestXMLState:
         mock_bootloader.return_value = [self.bootloader]
         assert self.state.get_build_type_bootloader_timeout_style() == \
             'some-style'
+        mock_bootloader.return_value = [None]
+        assert self.state.get_build_type_bootloader_timeout_style() \
+            is None
 
     @patch('kiwi.xml_parse.type_.get_bootloader')
     def test_get_build_type_bootloader_targettype(self, mock_bootloader):
